typecode
========
typecode provides file type detection functionality to ScanCode toolkit.

To install this package with its full capability (where the binaries for libmagic are installed), use the `full` option:
    pip install typecode[full]

If you want to use the version of libmagic provided by your operating system, use the `minimal` option:
    pip install typecode[minimal]

To set up the typecode development environment:
    source configure

To clean up development environment:
    ./configure --clean
